====================
 ``zope.container``
====================

.. image:: https://github.com/zopefoundation/zope.container/actions/workflows/tests.yml/badge.svg
        :target: https://github.com/zopefoundation/zope.container/actions/workflows/tests.yml

.. image:: https://ci.appveyor.com/api/projects/status/github/zopefoundation/zope.container?branch=master&svg=true
        :target: https://ci.appveyor.com/project/mgedmin/zope-container

.. image:: https://coveralls.io/repos/github/zopefoundation/zope.container/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/zope.container?branch=master

.. image:: https://readthedocs.org/projects/zopecontainer/badge/?version=latest
        :target: https://zopecontainer.readthedocs.io/en/latest/
        :alt: Documentation Status

.. image:: https://img.shields.io/pypi/v/zope.container.svg
        :target: https://pypi.python.org/pypi/zope.container/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/zope.container.svg
        :target: https://pypi.org/project/zope.container/
        :alt: Supported Python versions


This package define interfaces of container components, and provides
container implementations such as a BTreeContainer and
OrderedContainer, as well as the base class used by ``zope.site.folder``
for the Folder implementation.

Documentation is hosted at https://zopecontainer.readthedocs.io
